@@ -25,11 +25,11 @@ Marketplace::Ebay - Making API calls to eBay (with XSD validation)
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 =head1 SYNOPSIS
 
@@ -117,6 +117,10 @@ out of the return value of the last C<api_call>.
 
 A filename where to log requests and responses.
 
+=head3 name_from_shipping_address
+
+Passed to L<Marketplace::Ebay::Order>. Defaults to true.
+
 =cut
 
 has developer_key =>   (is => 'ro', required => 1);
@@ -125,6 +129,7 @@ has certificate_key => (is => 'ro', required => 1);
 has token =>           (is => 'ro', required => 1);
 has site_id =>         (is => 'ro', required => 1);
 has site_code => (is => 'lazy');
+has name_from_shipping_address => (is => 'ro', isa => Bool, default => sub { 1 });
 
 sub _build_site_code {
     my $self = shift;
@@ -324,8 +329,47 @@ expecting invalid structures, you should use C<api_call> directly.
 Return the response object. If no response object is found, it will
 die.
 
+=head2 api_call_wrapper_silent($call, $data, @ids)
+
+Same as C<api_call_wrapper>, but do not emit "warn" on warnings. Just
+print them out. Also, do not print ids or fees.
+
 =cut
 
+sub api_call_wrapper_silent {
+    my ($self, $call, $data, @identifiers) = @_;
+    my $res = $self->api_call($call, $data);
+    my $message = $call;
+    if (@identifiers) {
+        $message .= " on " . join(' ', @identifiers);
+    }
+    if ($res) {
+        if ($res->request_ok) {
+            if ($res->is_success) {
+                print "$message OK\n";
+            }
+            elsif ($res->errors) {
+                print "$message:\n" . $res->errors_as_string;
+            }
+            else {
+                print "$message not a success but no errors found (OK?)\n";
+            }
+        }
+        elsif ($res->errors) {
+            warn "$message:\n" . $res->errors_as_string;
+        }
+        else {
+            die "$message: Nor success, nor errors!" . Dumper($res);
+        }
+    }
+    else {
+        die "No response found!" . $self->last_response->status_line
+          . "\n" . $self->last_response->content;
+    }
+    return $res;
+}
+
+
 sub api_call_wrapper {
     my ($self, $call, $data, @identifiers) = @_;
     my $res = $self->api_call($call, $data);
@@ -467,12 +511,14 @@ sub get_orders {
     my $repeat = 1;
     my @orders;
     do {
-        my $obj = $self->api_call_wrapper(GetOrders => $request);
+        # we use the silent variant because it's a known warning spammer.
+        my $obj = $self->api_call_wrapper_silent(GetOrders => $request);
         my $res = $obj->struct;
         if (exists $res->{OrderArray} and
             exists $res->{OrderArray}->{Order}) {
             foreach my $ord (@{$res->{OrderArray}->{Order}}) {
-                push @orders, Marketplace::Ebay::Order->new(order => $ord);
+                push @orders, Marketplace::Ebay::Order->new(order => $ord,
+                                                            name_from_shipping_address => $self->name_from_shipping_address);
             }
         }
         $repeat = $res->{HasMoreOrders};
